@@ -3,8 +3,8 @@ import numpy as np
 from dplab.library_workload.util import read_input_file, workload_main
 
 
-def evaluate(query, input_file, eps, quant, repeat):
-    data = read_input_file(input_file)
+def evaluate(query, input_file, eps, quant, lb, ub, repeat):
+    data, pre_loading_time = read_input_file(input_file)
     results = []
     for i in range(repeat):
         if query == "count":
@@ -22,7 +22,7 @@ def evaluate(query, input_file, eps, quant, repeat):
         else:
             raise ValueError("Unknown query: {}".format(query))
         results.append(result)
-    return results
+    return results, {"loading_time": pre_loading_time, "pre_loading_time": pre_loading_time}
 
 
 if __name__ == "__main__":
